//////////////////////////////////////////////////////////////////////////////////////
//
//	Autor: 		Jens Wei
//	Date. 		12.09.2012
//
//	Projekt: 	Laser Exposer
//	Module: 	Motor Controller
//	Funktion: 	Der Motor Controller steuert den Polygonspiegel und sorgt
//				dafr, dass sich der Spiegel mit einer festen Geschwindigkeit dreht.
//				Die Frequenz wird so eingestellt, dass der Laser genau 3ms braucht 
//				fr eine Zeile.
//
//////////////////////////////////////////////////////////////////////////////////////

#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>
#include "pwm.h"
#include "regler.h"

volatile unsigned int pwm = 0;
volatile unsigned char locked = 0;
volatile unsigned char calc = 0;
volatile unsigned long int x = 0;			//Istwert
volatile unsigned long int w = 48000;		//Sollwert
volatile unsigned long int overflow = 0;

int main()
{
	pwm_init();
	timer_init();
	init_INT0();
	INT_PORT |= (1<<INT_PIN);	//Pull Up an INT0 einschhalten
	LED_DDR |= (1<<LED_BIT);	//Led PIN auf Ausgang

	set_pwm(500);				//Spiegel anlaufen lassen
	_delay_ms(1000);
	_delay_ms(1000);

	sei();
	
	while(1)
	{
		
	}	
}

ISR(TIMER0_OVF_vect)
{
	overflow++;
}

ISR(INT0_vect)
{	
	if(calc == 1)
	{
		TCCR0B &= ~((1<<CS01)|(1<<CS00));		//clk/8 prescaling (Timer off)
		calc = 0;	

		x = TCNT0;
		overflow = overflow * 256;
		x = x + overflow;
		x = x * 8;

		pwm = PI_Berechnung(x,w);	
		set_pwm(pwm);

		overflow = 0;
		TCNT0 = 0;
		x = 0;
	}
	else
	{		
		overflow = 0;
		TCNT0 = 0;
		calc = 1;
		TCCR0B |= (1<<CS01);		//clk/8 prescaling (Timer on)
	}
	EIFR |= (1<<INTF0);			//Interrupt lschen
}
